@@ -2,14 +2,18 @@ use super::{Client, State};
 use crate::ratelimiting::Ratelimiter;
 use hyper::header::HeaderMap;
 use std::{
-    sync::{atomic::AtomicBool, Arc},
+    sync::{
+        atomic::{AtomicBool, AtomicU64, Ordering},
+        Arc,
+    },
     time::Duration,
 };
-use twilight_model::channel::message::allowed_mentions::AllowedMentions;
+use twilight_model::{channel::message::allowed_mentions::AllowedMentions, id::ApplicationId};
 
 #[derive(Debug)]
 /// A builder for [`Client`].
 pub struct ClientBuilder {
+    pub(crate) application_id: AtomicU64,
     pub(crate) default_allowed_mentions: Option<AllowedMentions>,
     pub(crate) proxy: Option<Box<str>>,
     pub(crate) ratelimiter: Option<Ratelimiter>,
@@ -49,12 +53,21 @@ impl ClientBuilder {
                 timeout: self.timeout,
                 token_invalid: AtomicBool::new(false),
                 token: self.token,
+                application_id: self.application_id,
                 default_allowed_mentions: self.default_allowed_mentions,
                 use_http: self.use_http,
             }),
         }
     }
 
+    /// Set the [`ApplicationId`] used by interaction methods.
+    pub fn application_id(self, application_id: ApplicationId) -> Self {
+        self.application_id
+            .store(application_id.0, Ordering::Relaxed);
+
+        self
+    }
+
     /// Set the default allowed mentions setting to use on all messages sent through the HTTP
     /// client.
     pub fn default_allowed_mentions(mut self, allowed_mentions: AllowedMentions) -> Self {
@@ -141,6 +154,7 @@ impl ClientBuilder {
 impl Default for ClientBuilder {
     fn default() -> Self {
         Self {
+            application_id: AtomicU64::default(),
             default_allowed_mentions: None,
             default_headers: None,
             proxy: None,
