@@ -3,21 +3,29 @@ mod builder;
 pub use self::builder::ClientBuilder;
 
 use crate::{
-    api_error::{ApiError, ErrorCode},
-    error::{Error, ErrorType, Result},
+    api_error::ApiError,
+    error::{Error, ErrorType},
     ratelimiting::{RatelimitHeaders, Ratelimiter},
     request::{
-        channel::stage::{
-            create_stage_instance::CreateStageInstanceError,
-            update_stage_instance::UpdateStageInstanceError,
+        application::{
+            CreateFollowupMessage, CreateGlobalCommand, CreateGuildCommand, DeleteFollowupMessage,
+            DeleteGlobalCommand, DeleteGuildCommand, DeleteOriginalResponse, GetCommandPermissions,
+            GetGlobalCommands, GetGuildCommandPermissions, GetGuildCommands, InteractionCallback,
+            InteractionError, InteractionErrorType, SetCommandPermissions, SetGlobalCommands,
+            SetGuildCommands, UpdateCommandPermissions, UpdateFollowupMessage, UpdateGlobalCommand,
+            UpdateGuildCommand, UpdateOriginalResponse,
+        },
+        channel::stage::create_stage_instance::CreateStageInstanceError,
+        guild::{
+            create_guild::CreateGuildError, create_guild_channel::CreateGuildChannelError,
+            update_guild_channel_positions::Position,
         },
-        guild::{create_guild::CreateGuildError, create_guild_channel::CreateGuildChannelError},
         prelude::*,
         GetUserApplicationInfo, Method, Request,
     },
     API_VERSION,
 };
-use bytes::Bytes;
+use hyper::body::Bytes;
 use hyper::{
     body::{self, Buf},
     client::{Client as HyperClient, HttpConnector},
@@ -28,18 +36,24 @@ use serde::de::DeserializeOwned;
 use std::{
     convert::TryFrom,
     fmt::{Debug, Formatter, Result as FmtResult},
-    result::Result as StdResult,
     sync::{
-        atomic::{AtomicBool, Ordering},
+        atomic::{AtomicBool, AtomicU64, Ordering},
         Arc,
     },
     time::Duration,
 };
 use tokio::time;
 use twilight_model::{
+    application::{
+        callback::InteractionResponse,
+        command::{permissions::CommandPermissions, Command},
+    },
     channel::message::allowed_mentions::AllowedMentions,
     guild::Permissions,
-    id::{ChannelId, EmojiId, GuildId, IntegrationId, MessageId, RoleId, UserId, WebhookId},
+    id::{
+        ApplicationId, ChannelId, CommandId, EmojiId, GuildId, IntegrationId, InteractionId,
+        MessageId, RoleId, UserId, WebhookId,
+    },
 };
 
 #[cfg(feature = "hyper-rustls")]
@@ -56,6 +70,7 @@ struct State {
     token_invalid: AtomicBool,
     token: Option<Box<str>>,
     use_http: bool,
+    pub(crate) application_id: AtomicU64,
     pub(crate) default_allowed_mentions: Option<AllowedMentions>,
 }
 
@@ -164,6 +179,33 @@ impl Client {
         self.state.token.as_deref()
     }
 
+    /// Retrieve the [`ApplicationId`] used by interaction methods.
+    pub fn application_id(&self) -> Option<ApplicationId> {
+        let id = self.state.application_id.load(Ordering::Relaxed);
+
+        if id != 0 {
+            return Some(ApplicationId(id));
+        }
+
+        None
+    }
+
+    /// Set a new [`ApplicationId`] after building the client.
+    ///
+    /// Returns the previous ID, if there was one.
+    pub fn set_application_id(&self, application_id: ApplicationId) -> Option<ApplicationId> {
+        let prev = self
+            .state
+            .application_id
+            .swap(application_id.0, Ordering::Relaxed);
+
+        if prev != 0 {
+            return Some(ApplicationId(prev));
+        }
+
+        None
+    }
+
     /// Get the default [`AllowedMentions`] for sent messages.
     pub fn default_allowed_mentions(&self) -> Option<AllowedMentions> {
         self.state.default_allowed_mentions.clone()
@@ -639,7 +681,7 @@ impl Client {
     pub fn create_guild(
         &self,
         name: impl Into<String>,
-    ) -> StdResult<CreateGuild<'_>, CreateGuildError> {
+    ) -> Result<CreateGuild<'_>, CreateGuildError> {
         CreateGuild::new(self, name)
     }
 
@@ -690,17 +732,20 @@ impl Client {
         &self,
         guild_id: GuildId,
         name: impl Into<String>,
-    ) -> StdResult<CreateGuildChannel<'_>, CreateGuildChannelError> {
+    ) -> Result<CreateGuildChannel<'_>, CreateGuildChannelError> {
         CreateGuildChannel::new(self, guild_id, name)
     }
 
     /// Modify the positions of the channels.
     ///
     /// The minimum amount of channels to modify, is a swap between two channels.
+    ///
+    /// This function accepts an `Iterator` of `(ChannelId, u64)`. It also
+    /// accepts an `Iterator` of `Position`, which has extra fields.
     pub fn update_guild_channel_positions(
         &self,
         guild_id: GuildId,
-        channel_positions: impl Iterator<Item = (ChannelId, u64)>,
+        channel_positions: impl Iterator<Item = impl Into<Position>>,
     ) -> UpdateGuildChannelPositions<'_> {
         UpdateGuildChannelPositions::new(self, guild_id, channel_positions)
     }
@@ -798,10 +843,11 @@ impl Client {
     ///
     /// # Errors
     ///
-    /// Returns [`SearchGuildMembersError::LimitInvalid`] if the limit is invalid.
+    /// Returns a [`SearchGuildMembersErrorType::LimitInvalid`] error type if
+    /// the limit is invalid.
     ///
     /// [`GUILD_MEMBERS`]: ../../twilight_model/gateway/struct.Intents.html#associatedconstant.GUILD_MEMBERS
-    /// [`SearchGuildMembersError::LimitInvalid`]: ../request/guild/member/search_guild_members/enum.SearchGuildMembersError.html#variant.LimitInvalid
+    /// [`SearchGuildMembersErrorType::LimitInvalid`]: ../request/guild/member/search_guild_members/enum.SearchGuildMembersError.html#variant.LimitInvalid
     pub fn search_guild_members(
         &self,
         guild_id: GuildId,
@@ -1351,19 +1397,8 @@ impl Client {
     /// Update fields of an existing stage instance.
     ///
     /// Requires the user to be a moderator of the stage channel.
-    ///
-    /// # Errors
-    ///
-    /// Returns a [`UpdateStageInstanceError`] of type [`InvalidTopic`] when the
-    ///
-    /// [`InvalidTopic`]: crate::request::channel::stage::update_stage_instance::UpdateStageInstanceErrorType::InvalidTopic
-    /// topic is not between 1 and 120 characters in length.
-    pub fn update_stage_instance(
-        &self,
-        channel_id: ChannelId,
-        topic: impl Into<String>,
-    ) -> Result<UpdateStageInstance<'_>, UpdateStageInstanceError> {
-        UpdateStageInstance::new(self, channel_id, topic)
+    pub fn update_stage_instance(&self, channel_id: ChannelId) -> UpdateStageInstance<'_> {
+        UpdateStageInstance::new(self, channel_id)
     }
 
     /// Delete the stage instance of a stage channel.
@@ -1379,15 +1414,15 @@ impl Client {
     ///
     /// # Errors
     ///
-    /// Returns [`CreateGuildFromTemplateError::NameInvalid`] when the name is
-    /// invalid.
+    /// Returns a [`CreateGuildFromTemplateErrorType::NameInvalid`] error type
+    /// if the name is invalid.
     ///
-    /// [`CreateGuildFromTemplateError::NameInvalid`]: crate::request::template::create_guild_from_template::CreateGuildFromTemplateError::NameInvalid
+    /// [`CreateGuildFromTemplateErrorType::NameInvalid`]: crate::request::template::create_guild_from_template::CreateGuildFromTemplateErrorType::NameInvalid
     pub fn create_guild_from_template(
         &self,
         template_code: impl Into<String>,
         name: impl Into<String>,
-    ) -> StdResult<CreateGuildFromTemplate<'_>, CreateGuildFromTemplateError> {
+    ) -> Result<CreateGuildFromTemplate<'_>, CreateGuildFromTemplateError> {
         CreateGuildFromTemplate::new(self, template_code, name)
     }
 
@@ -1398,14 +1433,15 @@ impl Client {
     ///
     /// # Errors
     ///
-    /// Returns [`CreateTemplateError::NameInvalid`] when the name is invalid.
+    /// Returns a [`CreateTemplateErrorType::NameInvalid`] error type if the
+    /// name is invalid.
     ///
-    /// [`CreateTemplateError::NameInvalid`]: crate::request::template::create_template::CreateTemplateError::NameInvalid
+    /// [`CreateTemplateErrorType::NameInvalid`]: crate::request::template::create_template::CreateTemplateErrorType::NameInvalid
     pub fn create_template(
         &self,
         guild_id: GuildId,
         name: impl Into<String>,
-    ) -> StdResult<CreateTemplate<'_>, CreateTemplateError> {
+    ) -> Result<CreateTemplate<'_>, CreateTemplateError> {
         CreateTemplate::new(self, guild_id, name)
     }
 
@@ -1617,6 +1653,466 @@ impl Client {
         DeleteWebhookMessage::new(self, webhook_id, token, message_id)
     }
 
+    /// Respond to an interaction, by ID and token.
+    pub fn interaction_callback(
+        &self,
+        interaction_id: InteractionId,
+        interaction_token: impl Into<String>,
+        response: InteractionResponse,
+    ) -> InteractionCallback<'_> {
+        InteractionCallback::new(self, interaction_id, interaction_token, response)
+    }
+
+    /// Edit the original message, by its token.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn update_interaction_original(
+        &self,
+        interaction_token: impl Into<String>,
+    ) -> Result<UpdateOriginalResponse<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(UpdateOriginalResponse::new(
+            self,
+            application_id,
+            interaction_token,
+        ))
+    }
+
+    /// Delete the original message, by its token.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn delete_interaction_original(
+        &self,
+        interaction_token: impl Into<String>,
+    ) -> Result<DeleteOriginalResponse<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(DeleteOriginalResponse::new(
+            self,
+            application_id,
+            interaction_token,
+        ))
+    }
+
+    /// Create a followup message, by an interaction token.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn create_followup_message(
+        &self,
+        interaction_token: impl Into<String>,
+    ) -> Result<CreateFollowupMessage<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(CreateFollowupMessage::new(
+            self,
+            application_id,
+            interaction_token,
+        ))
+    }
+
+    /// Edit a followup message, by an interaction token.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn update_followup_message(
+        &self,
+        interaction_token: impl Into<String>,
+        message_id: MessageId,
+    ) -> Result<UpdateFollowupMessage<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(UpdateFollowupMessage::new(
+            self,
+            application_id,
+            interaction_token,
+            message_id,
+        ))
+    }
+
+    /// Delete a followup message by interaction token and the message's ID.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn delete_followup_message(
+        &self,
+        interaction_token: impl Into<String>,
+        message_id: MessageId,
+    ) -> Result<DeleteFollowupMessage<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(DeleteFollowupMessage::new(
+            self,
+            application_id,
+            interaction_token,
+            message_id,
+        ))
+    }
+
+    /// Create a new command in a guild.
+    ///
+    /// The name must be between 3 and 32 characters in length, and the
+    /// description must be between 1 and 100 characters in length. Creating a
+    /// guild command with the same name as an already-existing guild command in
+    /// the same guild will overwrite the old command. See [the discord docs]
+    /// for more information.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    ///
+    /// Returns an [`InteractionErrorType::CommandNameValidationFailed`]
+    /// error type if the command name is not between 3 and 32 characters.
+    ///
+    /// Returns an [`InteractionErrorType::CommandDescriptionValidationFailed`]
+    /// error type if the command description is not between 1 and
+    /// 100 characters.
+    ///
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#create-guild-application-command
+    pub fn create_guild_command(
+        &self,
+        guild_id: GuildId,
+        name: impl Into<String>,
+        description: impl Into<String>,
+    ) -> Result<CreateGuildCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        CreateGuildCommand::new(&self, application_id, guild_id, name, description)
+    }
+
+    /// Fetch all commands for a guild, by ID.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn get_guild_commands(
+        &self,
+        guild_id: GuildId,
+    ) -> Result<GetGuildCommands<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(GetGuildCommands::new(self, application_id, guild_id))
+    }
+
+    /// Edit a command in a guild, by ID.
+    ///
+    /// You must specify a name and description. See [the discord docs] for more
+    /// information.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    ///
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#edit-guild-application-command
+    pub fn update_guild_command(
+        &self,
+        guild_id: GuildId,
+        command_id: CommandId,
+    ) -> Result<UpdateGuildCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(UpdateGuildCommand::new(
+            self,
+            application_id,
+            guild_id,
+            command_id,
+        ))
+    }
+
+    /// Delete a command in a guild, by ID.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn delete_guild_command(
+        &self,
+        guild_id: GuildId,
+        command_id: CommandId,
+    ) -> Result<DeleteGuildCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(DeleteGuildCommand::new(
+            self,
+            application_id,
+            guild_id,
+            command_id,
+        ))
+    }
+
+    /// Set a guild's commands.
+    ///
+    /// This method is idempotent: it can be used on every start, without being
+    /// ratelimited if there aren't changes to the commands.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn set_guild_commands(
+        &self,
+        guild_id: GuildId,
+        commands: Vec<Command>,
+    ) -> Result<SetGuildCommands<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(SetGuildCommands::new(
+            self,
+            application_id,
+            guild_id,
+            commands,
+        ))
+    }
+
+    /// Create a new global command.
+    ///
+    /// The name must be between 3 and 32 characters in length, and the
+    /// description must be between 1 and 100 characters in length. Creating a
+    /// command with the same name as an already-existing global command will
+    /// overwrite the old command. See [the discord docs] for more information.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    ///
+    /// Returns an [`InteractionErrorType::CommandNameValidationFailed`]
+    /// error type if the command name is not between 3 and 32 characters.
+    ///
+    /// Returns an [`InteractionErrorType::CommandDescriptionValidationFailed`]
+    /// error type if the command description is not between 1 and
+    /// 100 characters.
+    ///
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#create-global-application-command
+    pub fn create_global_command(
+        &self,
+        name: impl Into<String>,
+        description: impl Into<String>,
+    ) -> Result<CreateGlobalCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        CreateGlobalCommand::new(self, application_id, name, description)
+    }
+
+    /// Fetch all global commands for your application.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn get_global_commands(&self) -> Result<GetGlobalCommands<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(GetGlobalCommands::new(self, application_id))
+    }
+
+    /// Edit a global command, by ID.
+    ///
+    /// You must specify a name and description. See [the discord docs] for more
+    /// information.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    ///
+    /// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#edit-global-application-command
+    pub fn update_global_command(
+        &self,
+        command_id: CommandId,
+    ) -> Result<UpdateGlobalCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(UpdateGlobalCommand::new(self, application_id, command_id))
+    }
+
+    /// Delete a global command, by ID.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn delete_global_command(
+        &self,
+        command_id: CommandId,
+    ) -> Result<DeleteGlobalCommand<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(DeleteGlobalCommand::new(self, application_id, command_id))
+    }
+
+    /// Set global commands.
+    ///
+    /// This method is idempotent: it can be used on every start, without being
+    /// ratelimited if there aren't changes to the commands.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn set_global_commands(
+        &self,
+        commands: Vec<Command>,
+    ) -> Result<SetGlobalCommands<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(SetGlobalCommands::new(self, application_id, commands))
+    }
+
+    /// Fetch command permissions for a command from the current application
+    /// in a guild.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn get_command_permissions(
+        &self,
+        guild_id: GuildId,
+        command_id: CommandId,
+    ) -> Result<GetCommandPermissions<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(GetCommandPermissions::new(
+            &self,
+            application_id,
+            guild_id,
+            command_id,
+        ))
+    }
+
+    /// Fetch command permissions for all commands from the current
+    /// application in a guild.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn get_guild_command_permissions(
+        &self,
+        guild_id: GuildId,
+    ) -> Result<GetGuildCommandPermissions<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        Ok(GetGuildCommandPermissions::new(
+            self,
+            application_id,
+            guild_id,
+        ))
+    }
+
+    /// Update command permissions for a single command in a guild.
+    ///
+    /// This overwrites the command permissions so the full set of permissions
+    /// have to be sent every time.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn update_command_permissions(
+        &self,
+        guild_id: GuildId,
+        command_id: CommandId,
+        permissions: Vec<CommandPermissions>,
+    ) -> Result<UpdateCommandPermissions<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        UpdateCommandPermissions::new(self, application_id, guild_id, command_id, permissions)
+    }
+
+    /// Update command permissions for all commands in a guild.
+    ///
+    /// This overwrites the command permissions so the full set of permissions
+    /// have to be sent every time.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
+    /// error type if an application ID has not been configured via
+    /// [`Client::set_application_id`].
+    pub fn set_command_permissions(
+        &self,
+        guild_id: GuildId,
+        permissions: impl Iterator<Item = (CommandId, CommandPermissions)>,
+    ) -> Result<SetCommandPermissions<'_>, InteractionError> {
+        let application_id = self.application_id().ok_or(InteractionError {
+            kind: InteractionErrorType::ApplicationIdNotPresent,
+        })?;
+
+        SetCommandPermissions::new(self, application_id, guild_id, permissions)
+    }
+
     /// Execute a request, returning the response.
     ///
     /// # Errors
@@ -1624,7 +2120,7 @@ impl Client {
     /// Returns an [`ErrorType::Unauthorized`] error type if the configured
     /// token has become invalid due to expiration, revokation, etc.
     #[allow(clippy::too_many_lines)]
-    pub async fn raw(&self, request: Request) -> Result<Response<Body>> {
+    pub async fn raw(&self, request: Request) -> Result<Response<Body>, Error> {
         if self.state.token_invalid.load(Ordering::Relaxed) {
             return Err(Error {
                 kind: ErrorType::Unauthorized,
@@ -1646,6 +2142,7 @@ impl Client {
         let host = self.state.proxy.as_deref().unwrap_or("discord.com");
 
         let url = format!("{}://{}/api/v{}/{}", protocol, host, API_VERSION, path);
+        #[cfg(feature = "tracing")]
         tracing::debug!("URL: {:?}", url);
 
         let mut builder = hyper::Request::builder()
@@ -1787,7 +2284,9 @@ impl Client {
             Ok(v) => {
                 let _res = tx.send(Some(v));
             }
+            #[allow(unused_variables)]
             Err(why) => {
+                #[cfg(feature = "tracing")]
                 tracing::warn!("header parsing failed: {:?}; {:?}", why, resp);
 
                 let _res = tx.send(None);
@@ -1803,7 +2302,7 @@ impl Client {
     ///
     /// Returns an [`ErrorType::Unauthorized`] error type if the configured
     /// token has become invalid due to expiration, revokation, etc.
-    pub async fn request<T: DeserializeOwned>(&self, request: Request) -> Result<T> {
+    pub async fn request<T: DeserializeOwned>(&self, request: Request) -> Result<T, Error> {
         let resp = self.make_request(request).await?;
 
         let mut buf = body::aggregate(resp.into_body())
@@ -1826,7 +2325,7 @@ impl Client {
         })
     }
 
-    pub(crate) async fn request_bytes(&self, request: Request) -> Result<Bytes> {
+    pub(crate) async fn request_bytes(&self, request: Request) -> Result<Bytes, Error> {
         let resp = self.make_request(request).await?;
 
         hyper::body::to_bytes(resp.into_body())
@@ -1845,13 +2344,13 @@ impl Client {
     ///
     /// Returns an [`ErrorType::Unauthorized`] error type if the configured
     /// token has become invalid due to expiration, revokation, etc.
-    pub async fn verify(&self, request: Request) -> Result<()> {
+    pub async fn verify(&self, request: Request) -> Result<(), Error> {
         self.make_request(request).await?;
 
         Ok(())
     }
 
-    async fn make_request(&self, request: Request) -> Result<Response<Body>> {
+    async fn make_request(&self, request: Request) -> Result<Response<Body>, Error> {
         let resp = self.raw(request).await?;
         let status = resp.status();
 
@@ -1860,11 +2359,17 @@ impl Client {
         }
 
         match status {
-            StatusCode::IM_A_TEAPOT => tracing::warn!(
-                "discord's api now runs off of teapots -- proceed to panic: {:?}",
-                resp,
-            ),
-            StatusCode::TOO_MANY_REQUESTS => tracing::warn!("429 response: {:?}", resp),
+            StatusCode::IM_A_TEAPOT => {
+                #[cfg(feature = "tracing")]
+                tracing::warn!(
+                    "discord's api now runs off of teapots -- proceed to panic: {:?}",
+                    resp,
+                );
+            }
+            StatusCode::TOO_MANY_REQUESTS => {
+                #[cfg(feature = "tracing")]
+                tracing::warn!("429 response: {:?}", resp);
+            }
             StatusCode::SERVICE_UNAVAILABLE => {
                 return Err(Error {
                     kind: ErrorType::ServiceUnavailable { response: resp },
@@ -1891,7 +2396,10 @@ impl Client {
             source: Some(Box::new(source)),
         })?;
 
+        #[cfg(feature = "tracing")]
         if let ApiError::General(ref general) = error {
+            use crate::api_error::ErrorCode;
+
             if let ErrorCode::Other(num) = general.code {
                 tracing::debug!("got unknown API error code variant: {}; {:?}", num, error);
             }
