@@ -3,7 +3,6 @@ use hyper::{Body, Response, StatusCode};
 use std::{
     error::Error as StdError,
     fmt::{Display, Formatter, Result as FmtResult},
-    result::Result as StdResult,
 };
 
 #[cfg(not(feature = "simd-json"))]
@@ -11,8 +10,6 @@ use serde_json::Error as JsonError;
 #[cfg(feature = "simd-json")]
 use simd_json::Error as JsonError;
 
-pub type Result<T, E = Error> = StdResult<T, E>;
-
 #[derive(Debug)]
 pub struct Error {
     pub(super) source: Option<Box<dyn StdError + Send + Sync>>,
@@ -54,12 +51,10 @@ impl Display for Error {
             ErrorType::CreatingHeader { name, .. } => {
                 write!(f, "Parsing the value for header {} failed", name)
             }
-            ErrorType::Formatting => f.write_str("Formatting a string failed"),
             ErrorType::Json => f.write_str("Given value couldn't be serialized"),
             ErrorType::Parsing { body, .. } => {
                 write!(f, "Response body couldn't be deserialized: {:?}", body)
             }
-            ErrorType::Ratelimiting => f.write_str("Ratelimiting failure"),
             ErrorType::RequestCanceled => {
                 f.write_str("Request was canceled either before or while being sent")
             }
@@ -97,12 +92,10 @@ pub enum ErrorType {
     CreatingHeader {
         name: String,
     },
-    Formatting,
     Json,
     Parsing {
         body: Vec<u8>,
     },
-    Ratelimiting,
     RequestCanceled,
     RequestError,
     RequestTimedOut,
