@@ -1,4 +1,10 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error as HttpError,
+    request::{self, validate, AuditLogReason, AuditLogReasonError, Pending, Request},
+    routing::Route,
+};
+use serde::Serialize;
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
@@ -212,12 +218,6 @@ impl<'a> CreateInvite<'a> {
         self
     }
 
-    /// Set the target user for this invite.
-    #[deprecated(since = "0.3.7", note = "Use `target_user_id` instead")]
-    pub fn target_user(self, target_user_id: UserId) -> Self {
-        self.target_user_id(target_user_id)
-    }
-
     /// Set the target type for this invite.
     pub fn target_type(mut self, target_type: TargetType) -> Self {
         self.fields.target_type.replace(target_type);
@@ -225,12 +225,6 @@ impl<'a> CreateInvite<'a> {
         self
     }
 
-    /// Set the target user type for this invite.
-    #[deprecated(since = "0.4.2", note = "Use `target_type` instead")]
-    pub fn target_user_type(self, target_user_type: TargetType) -> Self {
-        Self::target_type(self, target_user_type)
-    }
-
     /// Specify true if the invite should grant temporary membership.
     ///
     /// Defaults to false.
@@ -252,14 +246,14 @@ impl<'a> CreateInvite<'a> {
         self
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), HttpError> {
         let mut request = Request::builder(Route::CreateInvite {
             channel_id: self.channel_id.0,
         })
         .json(&self.fields)?;
 
         if let Some(reason) = &self.reason {
-            request = request.headers(audit_header(reason)?);
+            request = request.headers(request::audit_header(reason)?);
         }
 
         self.fut
