@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{PendingOption, Request},
+    routing::Route,
+};
 use twilight_model::invite::Invite;
 
 #[derive(Default)]
@@ -62,7 +67,7 @@ impl<'a> GetInvite<'a> {
         self
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::GetInviteWithExpiration {
             code: self.code.clone(),
             with_counts: self.fields.with_counts,
