@@ -1,4 +1,10 @@
-use crate::request::{multipart::Form, prelude::*};
+use crate::{
+    client::Client,
+    error::Error as HttpError,
+    request::{multipart::Form, validate, Pending, Request},
+    routing::Route,
+};
+use serde::Serialize;
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
@@ -143,23 +149,6 @@ impl<'a> CreateMessage<'a> {
         self
     }
 
-    /// Attach a new file to the message.
-    ///
-    /// The file is raw binary data. It can be an image, or any other kind of file.
-    #[deprecated(since = "0.4.1", note = "use `file` instead")]
-    pub fn attachment(self, name: impl Into<String>, file: impl Into<Vec<u8>>) -> Self {
-        Self::file(self, name, file)
-    }
-
-    /// Insert multiple attachments into the message.
-    #[deprecated(since = "0.4.1", note = "use `files` instead")]
-    pub fn attachments<N: Into<String>, F: Into<Vec<u8>>>(
-        self,
-        attachments: impl IntoIterator<Item = (N, F)>,
-    ) -> Self {
-        Self::files(self, attachments)
-    }
-
     /// Set the content of the message.
     ///
     /// The maximum length is 2000 UTF-16 characters.
@@ -303,7 +292,7 @@ impl<'a> CreateMessage<'a> {
         self
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), HttpError> {
         let mut request = Request::builder(Route::CreateMessage {
             channel_id: self.channel_id.0,
         });
