@@ -1,4 +1,10 @@
-use crate::request::prelude::*;
+use super::RequestReactionType;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::id::{ChannelId, MessageId};
 
 /// Delete one reaction by a user on a message.
@@ -29,7 +35,7 @@ impl<'a> DeleteReaction<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::DeleteReaction {
             channel_id: self.channel_id.0,
             emoji: self.emoji.clone(),
