@@ -1,4 +1,10 @@
-use crate::request::prelude::*;
+use super::RequestReactionType;
+use crate::{
+    client::Client,
+    error::Error as HttpError,
+    request::{validate, Pending, Request},
+    routing::Route,
+};
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
@@ -59,7 +65,6 @@ pub enum GetReactionsErrorType {
 #[derive(Default)]
 struct GetReactionsFields {
     after: Option<UserId>,
-    before: Option<UserId>,
     limit: Option<u64>,
 }
 
@@ -100,13 +105,6 @@ impl<'a> GetReactions<'a> {
         self
     }
 
-    /// Get users before this id.
-    pub fn before(mut self, before: UserId) -> Self {
-        self.fields.before.replace(before);
-
-        self
-    }
-
     /// Set the maximum number of users to retrieve.
     ///
     /// The minimum is 1 and the maximum is 100. If no limit is specified, Discord sets the default
@@ -128,10 +126,9 @@ impl<'a> GetReactions<'a> {
         Ok(self)
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), HttpError> {
         let request = Request::from_route(Route::GetReactionUsers {
             after: self.fields.after.map(|x| x.0),
-            before: self.fields.before.map(|x| x.0),
             channel_id: self.channel_id.0,
             emoji: self.emoji.clone(),
             limit: self.fields.limit,
