@@ -2,10 +2,8 @@
 
 use crate::{
     client::Client,
-    error::{Error as HttpError, Result},
-    request::{
-        audit_header, validate, AuditLogReason, AuditLogReasonError, Form, Pending, Request,
-    },
+    error::Error as HttpError,
+    request::{self, validate, AuditLogReason, AuditLogReasonError, Form, Pending, Request},
     routing::Route,
 };
 use serde::Serialize;
@@ -358,7 +356,7 @@ impl<'a> UpdateWebhookMessage<'a> {
         self
     }
 
-    fn request(&mut self) -> Result<Request> {
+    fn request(&mut self) -> Result<Request, HttpError> {
         let mut request = Request::builder(Route::UpdateWebhookMessage {
             message_id: self.message_id.0,
             token: self.token.clone(),
@@ -386,13 +384,13 @@ impl<'a> UpdateWebhookMessage<'a> {
         }
 
         if let Some(reason) = self.reason.as_ref() {
-            request = request.headers(audit_header(reason)?);
+            request = request.headers(request::audit_header(reason)?);
         }
 
         Ok(request.build())
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), HttpError> {
         let request = self.request()?;
         self.fut.replace(Box::pin(self.http.verify(request)));
 
