@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::id::GuildId;
 
 /// Delete a guild permanently. The user must be the owner.
@@ -17,7 +22,7 @@ impl<'a> DeleteGuild<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::DeleteGuild {
             guild_id: self.guild_id.0,
         });
