@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::{guild::Emoji, id::GuildId};
 
 /// Get the emojis for a guild, by the guild's id.
@@ -35,7 +40,7 @@ impl<'a> GetEmojis<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::GetEmojis {
             guild_id: self.guild_id.0,
         });
