@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{self, AuditLogReason, AuditLogReasonError, Pending, Request},
+    routing::Route,
+};
 use twilight_model::id::{GuildId, RoleId, UserId};
 
 /// Add a role to a member in a guild.
@@ -48,7 +53,7 @@ impl<'a> AddRoleToMember<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let mut request = Request::builder(Route::AddMemberRole {
             guild_id: self.guild_id.0,
             role_id: self.role_id.0,
@@ -56,7 +61,7 @@ impl<'a> AddRoleToMember<'a> {
         });
 
         if let Some(reason) = self.reason.as_ref() {
-            request = request.headers(audit_header(reason)?);
+            request = request.headers(request::audit_header(reason)?);
         }
 
         self.fut
