@@ -1,4 +1,10 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error as HttpError,
+    request::{self, validate, AuditLogReason, AuditLogReasonError, Pending, Request},
+    routing::Route,
+};
+use serde::Serialize;
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
@@ -91,9 +97,6 @@ struct UpdateGuildFields {
     owner_id: Option<UserId>,
     #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
-    region: Option<Option<String>>,
-    #[allow(clippy::option_option)]
-    #[serde(skip_serializing_if = "Option::is_none")]
     splash: Option<Option<String>>,
     #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -259,16 +262,6 @@ impl<'a> UpdateGuild<'a> {
         self
     }
 
-    /// Specify the voice server region for the guild. Refer to [the discord docs] for more
-    /// information.
-    ///
-    /// [the discord docs]: https://discord.com/developers/docs/resources/voice#voice-region-object
-    pub fn region(mut self, region: impl Into<Option<String>>) -> Self {
-        self.fields.region.replace(region.into());
-
-        self
-    }
-
     /// Set the guild's splash image.
     ///
     /// Requires the guild to have the `INVITE_SPLASH` feature enabled.
@@ -351,14 +344,14 @@ impl<'a> UpdateGuild<'a> {
         self
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), HttpError> {
         let mut request = Request::builder(Route::UpdateGuild {
             guild_id: self.guild_id.0,
         })
         .json(&self.fields)?;
 
         if let Some(reason) = &self.reason {
-            request = request.headers(audit_header(reason)?)
+            request = request.headers(request::audit_header(reason)?)
         }
 
         self.fut
