@@ -1,4 +1,10 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
+use serde::Serialize;
 use twilight_model::{
     id::GuildId,
     invite::{WelcomeScreen, WelcomeScreenChannel},
@@ -64,7 +70,7 @@ impl<'a> UpdateGuildWelcomeScreen<'a> {
         self
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::builder(Route::UpdateGuildWelcomeScreen {
             guild_id: self.guild_id.0,
         })
