@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Pending, Request},
+    routing::Route,
+};
 use twilight_model::user::CurrentUser;
 
 /// Get information about the current user.
@@ -12,7 +17,7 @@ impl<'a> GetCurrentUser<'a> {
         Self { fut: None, http }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::GetUser {
             target_user: "@me".to_owned(),
         });
