@@ -76,6 +76,14 @@ pub enum PathParseErrorType {
 #[derive(Clone, Debug, Eq, Hash, PartialEq)]
 #[non_exhaustive]
 pub enum Path {
+    /// Operating on global commands.
+    ApplicationCommand(u64),
+    /// Operating on a specific command.
+    ApplicationCommandId(u64),
+    /// Operating on commands in a guild.
+    ApplicationGuildCommand(u64),
+    /// Operating on a specific command in a guild.
+    ApplicationGuildCommandId(u64),
     /// Operating on a channel.
     ChannelsId(u64),
     /// Operating on a channel's invites.
@@ -144,6 +152,8 @@ pub enum Path {
     GuildsIdWelcomeScreen(u64),
     GuildsIdWebhooks(u64),
     InvitesCode,
+    /// Operating on an interaction's callback.
+    InteractionCallback(u64),
     StageInstances,
     UsersId,
     OauthApplicationsMe,
@@ -182,7 +192,7 @@ impl FromStr for Path {
     /// );
     /// # Ok(()) }
     /// ```
-    #[allow(clippy::enum_glob_use)]
+    #[allow(clippy::enum_glob_use, clippy::too_many_lines)]
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         use Path::*;
 
@@ -198,6 +208,16 @@ impl FromStr for Path {
         let parts = s.split('/').skip(skip).collect::<Vec<&str>>();
 
         Ok(match parts.as_slice() {
+            ["applications", id, "commands"] => ApplicationCommand(parse_id(id)?),
+            ["applications", id, "commands", _] => ApplicationCommandId(parse_id(id)?),
+            ["applications", id, "guilds", _, "commands"]
+            | ["applications", id, "guilds", _, "commands", "permissions"] => {
+                ApplicationGuildCommand(parse_id(id)?)
+            }
+            ["applications", id, "guilds", _, "commands", _]
+            | ["applications", id, "guilds", _, "commands", _, "permissions"] => {
+                ApplicationGuildCommandId(parse_id(id)?)
+            }
             ["channels", id] => ChannelsId(parse_id(id)?),
             ["channels", id, "followers"] => ChannelsIdFollowers(parse_id(id)?),
             ["channels", id, "invites"] => ChannelsIdInvites(parse_id(id)?),
@@ -268,6 +288,7 @@ impl FromStr for Path {
             ["guilds", id, "welcome-screen"] => GuildsIdWelcomeScreen(parse_id(id)?),
             ["guilds", id, "webhooks"] => GuildsIdWebhooks(parse_id(id)?),
             ["invites", _] => InvitesCode,
+            ["interactions", id, _, "callback"] => InteractionCallback(parse_id(id)?),
             ["stage-instances", _] => StageInstances,
             ["oauth2", "applications", "@me"] => OauthApplicationsMe,
             ["users", _] => UsersId,
@@ -341,8 +362,20 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to create a global command.
+    CreateGlobalCommand {
+        /// The ID of the owner application.
+        application_id: u64,
+    },
     /// Route information to create a guild.
     CreateGuild,
+    /// Route information to create a guild command.
+    CreateGuildCommand {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to create a guild from a template.
     CreateGuildFromTemplate {
         /// Code of the template.
@@ -442,11 +475,27 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to delete a global command.
+    DeleteGlobalCommand {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the command.
+        command_id: u64,
+    },
     /// Route information to delete a guild.
     DeleteGuild {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to delete a guild command.
+    DeleteGuildCommand {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the command.
+        command_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to delete a guild integration.
     DeleteGuildIntegration {
         /// The ID of the guild.
@@ -459,6 +508,13 @@ pub enum Route {
         /// The unique invite code.
         code: String,
     },
+    /// Route information to delete the original interaction response.
+    DeleteInteractionOriginal {
+        /// The ID of the owner application
+        application_id: u64,
+        /// The token of the interaction.
+        interaction_token: String,
+    },
     /// Route information to delete a channel's message.
     DeleteMessage {
         /// The ID of the channel.
@@ -480,7 +536,7 @@ pub enum Route {
     },
     /// Route information to delete all of the reactions on a message with a
     /// specific emoji.
-    DeleteMessageSpecficReaction {
+    DeleteMessageSpecificReaction {
         /// The ID of the channel.
         channel_id: u64,
         /// The URI encoded custom or unicode emoji.
@@ -598,6 +654,15 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to get permissions of a specific guild command.
+    GetCommandPermissions {
+        /// The ID of the application.
+        application_id: u64,
+        /// The ID of the command.
+        command_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to get info about application the current bot user belongs to
     GetCurrentUserApplicationInfo,
     /// Route information to get an emoji by ID within a guild.
@@ -617,6 +682,10 @@ pub enum Route {
     /// Route information to get gateway information tailored to the current
     /// user.
     GetGatewayBot,
+    GetGlobalCommands {
+        /// The ID of the owner application.
+        application_id: u64,
+    },
     /// Route information to get a guild.
     GetGuild {
         /// The ID of the guild.
@@ -625,6 +694,20 @@ pub enum Route {
         /// guild.
         with_counts: bool,
     },
+    /// Route information to get permissions of all guild commands.
+    GetGuildCommandPermissions {
+        /// The ID of the application.
+        application_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
+    /// Route information to get guild commands.
+    GetGuildCommands {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to get a guild's widget.
     GetGuildWidget {
         /// The ID of the guild.
@@ -757,8 +840,6 @@ pub enum Route {
     GetReactionUsers {
         /// The minimum ID of users to get.
         after: Option<u64>,
-        /// The maximum ID of users to get.
-        before: Option<u64>,
         /// The ID of the channel.
         channel_id: u64,
         /// The URI encoded custom or unicode emoji.
@@ -812,6 +893,13 @@ pub enum Route {
         /// ID of the webhook.
         webhook_id: u64,
     },
+    /// Route information to respond to an interaction.
+    InteractionCallback {
+        /// The ID of the interaction.
+        interaction_id: u64,
+        /// The token for the interaction.
+        interaction_token: String,
+    },
     /// Route information to leave the guild.
     LeaveGuild {
         /// The ID of the guild.
@@ -849,6 +937,25 @@ pub enum Route {
         /// Query to search by.
         query: String,
     },
+    /// Route information to set permissions of commands in a guild.
+    SetCommandPermissions {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
+    /// Route information to set global commands.
+    SetGlobalCommands {
+        /// The ID of the owner application.
+        application_id: u64,
+    },
+    /// Route information to set guild commands.
+    SetGuildCommands {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to sync a guild's integration.
     SyncGuildIntegration {
         /// The ID of the guild.
@@ -875,6 +982,15 @@ pub enum Route {
         /// The ID of the channel.
         channel_id: u64,
     },
+    /// Route information to edit permissions of a command in a guild.
+    UpdateCommandPermissions {
+        /// The ID of the application.
+        application_id: u64,
+        /// The ID of the command.
+        command_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to update the current user.
     UpdateCurrentUser,
     /// Route information to update the current user's voice state.
@@ -889,6 +1005,13 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to update a global command.
+    UpdateGlobalCommand {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the command.
+        command_id: u64,
+    },
     /// Route information to update a guild.
     UpdateGuild {
         /// The ID of the guild.
@@ -899,6 +1022,15 @@ pub enum Route {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to update a guild command.
+    UpdateGuildCommand {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The ID of the command.
+        command_id: u64,
+        /// The ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to update a guild's widget.
     UpdateGuildWidget {
         /// The ID of the guild.
@@ -916,6 +1048,13 @@ pub enum Route {
         /// ID of the guild.
         guild_id: u64,
     },
+    /// Update the original interaction response.
+    UpdateInteractionOriginal {
+        /// The ID of the owner application.
+        application_id: u64,
+        /// The token for the interaction.
+        interaction_token: String,
+    },
     /// Route information to update a member.
     UpdateMember {
         /// The ID of the guild.
@@ -1046,12 +1185,29 @@ impl Route {
                 Path::GuildsIdEmojis(guild_id),
                 format!("guilds/{}/emojis", guild_id).into(),
             ),
+            Self::CreateGlobalCommand { application_id } => (
+                Method::Post,
+                Path::ApplicationCommand(application_id),
+                format!("applications/{}/commands", application_id).into(),
+            ),
             Self::CreateGuild => (Method::Post, Path::Guilds, "guilds".into()),
             Self::CreateGuildFromTemplate { template_code } => (
                 Method::Post,
                 Path::Guilds,
                 format!("guilds/templates/{}", template_code).into(),
             ),
+            Self::CreateGuildCommand {
+                application_id,
+                guild_id,
+            } => (
+                Method::Post,
+                Path::ApplicationGuildCommand(application_id),
+                format!(
+                    "applications/{}/guilds/{}/commands",
+                    application_id, guild_id
+                )
+                .into(),
+            ),
             Self::CreateGuildIntegration { guild_id } => (
                 Method::Post,
                 Path::GuildsIdIntegrationsId(guild_id),
@@ -1161,11 +1317,32 @@ impl Route {
                 Path::GuildsIdEmojisId(guild_id),
                 format!("guilds/{}/emojis/{}", guild_id, emoji_id).into(),
             ),
+            Self::DeleteGlobalCommand {
+                application_id,
+                command_id,
+            } => (
+                Method::Delete,
+                Path::ApplicationCommandId(application_id),
+                format!("applications/{}/commands/{}", application_id, command_id).into(),
+            ),
             Self::DeleteGuild { guild_id } => (
                 Method::Delete,
                 Path::GuildsId(guild_id),
                 format!("guilds/{}", guild_id).into(),
             ),
+            Self::DeleteGuildCommand {
+                application_id,
+                command_id,
+                guild_id,
+            } => (
+                Method::Delete,
+                Path::ApplicationGuildCommand(application_id),
+                format!(
+                    "applications/{}/guilds/{}/commands/{}",
+                    application_id, guild_id, command_id
+                )
+                .into(),
+            ),
             Self::DeleteGuildIntegration {
                 guild_id,
                 integration_id,
@@ -1179,6 +1356,18 @@ impl Route {
                 Path::InvitesCode,
                 format!("invites/{}", code).into(),
             ),
+            Self::DeleteInteractionOriginal {
+                application_id,
+                interaction_token,
+            } => (
+                Method::Delete,
+                Path::WebhooksIdTokenMessagesId(application_id),
+                format!(
+                    "webhooks/{}/{}/messages/@original",
+                    application_id, interaction_token
+                )
+                .into(),
+            ),
             Self::DeleteMessageReactions {
                 channel_id,
                 message_id,
@@ -1187,7 +1376,7 @@ impl Route {
                 Path::ChannelsIdMessagesIdReactions(channel_id),
                 format!("channels/{}/messages/{}/reactions", channel_id, message_id).into(),
             ),
-            Self::DeleteMessageSpecficReaction {
+            Self::DeleteMessageSpecificReaction {
                 channel_id,
                 message_id,
                 emoji,
@@ -1348,6 +1537,19 @@ impl Route {
                 Path::GuildsIdChannels(guild_id),
                 format!("guilds/{}/channels", guild_id).into(),
             ),
+            Self::GetCommandPermissions {
+                application_id,
+                command_id,
+                guild_id,
+            } => (
+                Method::Get,
+                Path::ApplicationGuildCommandId(application_id),
+                format!(
+                    "/applications/{}/guilds/{}/commands/{}/permissions",
+                    application_id, guild_id, command_id
+                )
+                .into(),
+            ),
             Self::GetCurrentUserApplicationInfo => (
                 Method::Get,
                 Path::OauthApplicationsMe,
@@ -1364,6 +1566,11 @@ impl Route {
                 format!("guilds/{}/emojis", guild_id).into(),
             ),
             Self::GetGateway => (Method::Get, Path::Gateway, "gateway".into()),
+            Self::GetGlobalCommands { application_id } => (
+                Method::Get,
+                Path::ApplicationCommand(application_id),
+                format!("applications/{}/commands", application_id).into(),
+            ),
             Self::GetGuild {
                 guild_id,
                 with_counts,
@@ -1374,6 +1581,30 @@ impl Route {
                 }
                 (Method::Get, Path::GuildsId(guild_id), path.into())
             }
+            Self::GetGuildCommandPermissions {
+                application_id,
+                guild_id,
+            } => (
+                Method::Get,
+                Path::ApplicationGuildCommand(application_id),
+                format!(
+                    "/applications/{}/guilds/{}/commands/permissions",
+                    application_id, guild_id
+                )
+                .into(),
+            ),
+            Self::GetGuildCommands {
+                application_id,
+                guild_id,
+            } => (
+                Method::Get,
+                Path::ApplicationGuildCommand(application_id),
+                format!(
+                    "applications/{}/guilds/{}/commands",
+                    application_id, guild_id
+                )
+                .into(),
+            ),
             Self::GetGuildWidget { guild_id } => (
                 Method::Get,
                 Path::GuildsIdWidget(guild_id),
@@ -1559,7 +1790,6 @@ impl Route {
             ),
             Self::GetReactionUsers {
                 after,
-                before,
                 channel_id,
                 ref emoji,
                 limit,
@@ -1574,10 +1804,6 @@ impl Route {
                     let _ = write!(path, "after={}", after);
                 }
 
-                if let Some(before) = before {
-                    let _ = write!(path, "before={}", before);
-                }
-
                 if let Some(limit) = limit {
                     let _ = write!(path, "&limit={}", limit);
                 }
@@ -1638,6 +1864,18 @@ impl Route {
                 Path::WebhooksIdTokenMessagesId(webhook_id),
                 format!("webhooks/{}/{}/messages/{}", webhook_id, token, message_id).into(),
             ),
+            Self::InteractionCallback {
+                interaction_id,
+                interaction_token,
+            } => (
+                Method::Post,
+                Path::InteractionCallback(interaction_id),
+                format!(
+                    "interactions/{}/{}/callback",
+                    interaction_id, interaction_token
+                )
+                .into(),
+            ),
             Self::LeaveGuild { guild_id } => (
                 Method::Delete,
                 Path::UsersIdGuildsId,
@@ -1682,6 +1920,35 @@ impl Route {
                     path.into(),
                 )
             }
+            Self::SetCommandPermissions {
+                application_id,
+                guild_id,
+            } => (
+                Method::Put,
+                Path::ApplicationGuildCommand(application_id),
+                format!(
+                    "/applications/{}/guilds/{}/commands/permissions",
+                    application_id, guild_id
+                )
+                .into(),
+            ),
+            Self::SetGlobalCommands { application_id } => (
+                Method::Put,
+                Path::ApplicationCommand(application_id),
+                format!("applications/{}/commands", application_id).into(),
+            ),
+            Self::SetGuildCommands {
+                application_id,
+                guild_id,
+            } => (
+                Method::Put,
+                Path::ApplicationGuildCommand(application_id),
+                format!(
+                    "applications/{}/guilds/{}/commands",
+                    application_id, guild_id
+                )
+                .into(),
+            ),
             Self::SyncGuildIntegration {
                 guild_id,
                 integration_id,
@@ -1711,6 +1978,19 @@ impl Route {
                 Path::ChannelsId(channel_id),
                 format!("channels/{}", channel_id).into(),
             ),
+            Self::UpdateCommandPermissions {
+                application_id,
+                command_id,
+                guild_id,
+            } => (
+                Method::Put,
+                Path::ApplicationGuildCommandId(application_id),
+                format!(
+                    "/applications/{}/guilds/{}/commands/{}/permissions",
+                    application_id, guild_id, command_id
+                )
+                .into(),
+            ),
             Self::UpdateCurrentUser => (Method::Patch, Path::UsersId, "users/@me".into()),
             Self::UpdateCurrentUserVoiceState { guild_id } => (
                 Method::Patch,
@@ -1722,11 +2002,32 @@ impl Route {
                 Path::GuildsIdEmojisId(guild_id),
                 format!("guilds/{}/emojis/{}", guild_id, emoji_id).into(),
             ),
+            Self::UpdateGlobalCommand {
+                application_id,
+                command_id,
+            } => (
+                Method::Patch,
+                Path::ApplicationCommandId(application_id),
+                format!("applications/{}/commands/{}", application_id, command_id).into(),
+            ),
             Self::UpdateGuild { guild_id } => (
                 Method::Patch,
                 Path::GuildsId(guild_id),
                 format!("guilds/{}", guild_id).into(),
             ),
+            Self::UpdateGuildCommand {
+                application_id,
+                command_id,
+                guild_id,
+            } => (
+                Method::Patch,
+                Path::ApplicationGuildCommand(application_id),
+                format!(
+                    "applications/{}/guilds/{}/commands/{}",
+                    application_id, guild_id, command_id
+                )
+                .into(),
+            ),
             Self::UpdateGuildChannels { guild_id } => (
                 Method::Patch,
                 Path::GuildsIdChannels(guild_id),
@@ -1750,6 +2051,18 @@ impl Route {
                 Path::GuildsIdWelcomeScreen(guild_id),
                 format!("guilds/{}/welcome-screen", guild_id).into(),
             ),
+            Self::UpdateInteractionOriginal {
+                application_id,
+                interaction_token,
+            } => (
+                Method::Patch,
+                Path::WebhooksIdTokenMessagesId(application_id),
+                format!(
+                    "webhooks/{}/{}/messages/@original",
+                    application_id, interaction_token
+                )
+                .into(),
+            ),
             Self::UpdateMember { guild_id, user_id } => (
                 Method::Patch,
                 Path::GuildsIdMembersId(guild_id),
@@ -1829,10 +2142,17 @@ impl Route {
 
 #[cfg(test)]
 mod tests {
-    use super::{Path, PathParseErrorType};
+    use super::{Path, PathParseErrorType, Route};
     use crate::request::Method;
+    use static_assertions::assert_fields;
     use std::{convert::TryFrom, error::Error, str::FromStr};
 
+    assert_fields!(
+        Route::DeleteMessageSpecificReaction: channel_id,
+        emoji,
+        message_id
+    );
+
     #[test]
     fn test_path_prefix_unimportant() -> Result<(), Box<dyn Error>> {
         assert_eq!(Path::Guilds, Path::from_str("guilds")?);
